==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/devices/kotlin/DpsCertificate.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devices.kotlin

import com.pulumi.azurenative.devices.kotlin.outputs.CertificatePropertiesResponse
import com.pulumi.azurenative.devices.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import com.pulumi.azurenative.devices.kotlin.outputs.CertificatePropertiesResponse.Companion.toKotlin as certificatePropertiesResponseToKotlin
import com.pulumi.azurenative.devices.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [DpsCertificate].
 */
@PulumiTagMarker
public class DpsCertificateResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: DpsCertificateArgs = DpsCertificateArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend DpsCertificateArgsBuilder.() -> Unit) {
        val builder = DpsCertificateArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): DpsCertificate {
        val builtJavaResource = com.pulumi.azurenative.devices.DpsCertificate(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return DpsCertificate(builtJavaResource)
    }
}

/**
 * The X509 Certificate.
 * Azure REST API version: 2022-12-12. Prior API version in Azure Native 1.x: 2020-03-01.
 * Other available API versions: 2021-10-15, 2023-03-01-preview.
 * ## Example Usage
 * ### DPSCreateOrUpdateCertificate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var dpsCertificate = new AzureNative.Devices.DpsCertificate("dpsCertificate", new()
 *     {
 *         CertificateName = "cert",
 *         Properties = new AzureNative.Devices.Inputs.CertificatePropertiesArgs
 *         {
 *             Certificate = "MA==",
 *         },
 *         ProvisioningServiceName = "myFirstProvisioningService",
 *         ResourceGroupName = "myResourceGroup",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/devices/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := devices.NewDpsCertificate(ctx, "dpsCertificate", &devices.DpsCertificateArgs{
 * 			CertificateName: pulumi.String("cert"),
 * 			Properties: &devices.CertificatePropertiesArgs{
 * 				Certificate: pulumi.String("MA=="),
 * 			},
 * 			ProvisioningServiceName: pulumi.String("myFirstProvisioningService"),
 * 			ResourceGroupName:       pulumi.String("myResourceGroup"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.devices.DpsCertificate;
 * import com.pulumi.azurenative.devices.DpsCertificateArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var dpsCertificate = new DpsCertificate("dpsCertificate", DpsCertificateArgs.builder()
 *             .certificateName("cert")
 *             .properties(Map.of("certificate", "MA=="))
 *             .provisioningServiceName("myFirstProvisioningService")
 *             .resourceGroupName("myResourceGroup")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:devices:DpsCertificate cert /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Devices/provisioningServices/{provisioningServiceName}/certificates/{certificateName}
 * ```
 */
public class DpsCertificate internal constructor(
    override val javaResource: com.pulumi.azurenative.devices.DpsCertificate,
) : KotlinCustomResource(javaResource, DpsCertificateMapper) {
    /**
     * The entity tag.
     */
    public val etag: Output<String>
        get() = javaResource.etag().applyValue({ args0 -> args0 })

    /**
     * The name of the certificate.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * properties of a certificate
     */
    public val properties: Output<CertificatePropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.let({ args0 ->
                certificatePropertiesResponseToKotlin(args0)
            })
        })

    /**
     * Metadata pertaining to creation and last modification of the resource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * The resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object DpsCertificateMapper : ResourceMapper<DpsCertificate> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.devices.DpsCertificate::class == javaResource::class

    override fun map(javaResource: Resource): DpsCertificate = DpsCertificate(
        javaResource as
            com.pulumi.azurenative.devices.DpsCertificate,
    )
}

/**
 * @see [DpsCertificate].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [DpsCertificate].
 */
public suspend fun dpsCertificate(
    name: String,
    block: suspend DpsCertificateResourceBuilder.() -> Unit,
): DpsCertificate {
    val builder = DpsCertificateResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [DpsCertificate].
 * @param name The _unique_ name of the resulting resource.
 */
public fun dpsCertificate(name: String): DpsCertificate {
    val builder = DpsCertificateResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/devices/kotlin/DpsCertificate.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devices.kotlin

import com.pulumi.azurenative.devices.kotlin.outputs.CertificatePropertiesResponse
import com.pulumi.azurenative.devices.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import com.pulumi.azurenative.devices.kotlin.outputs.CertificatePropertiesResponse.Companion.toKotlin as certificatePropertiesResponseToKotlin
import com.pulumi.azurenative.devices.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [DpsCertificate].
 */
@PulumiTagMarker
public class DpsCertificateResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: DpsCertificateArgs = DpsCertificateArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend DpsCertificateArgsBuilder.() -> Unit) {
        val builder = DpsCertificateArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): DpsCertificate {
        val builtJavaResource = com.pulumi.azurenative.devices.DpsCertificate(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return DpsCertificate(builtJavaResource)
    }
}

/**
 * The X509 Certificate.
 * Azure REST API version: 2022-12-12. Prior API version in Azure Native 1.x: 2020-03-01.
 * Other available API versions: 2021-10-15, 2023-03-01-preview.
 * ## Example Usage
 * ### DPSCreateOrUpdateCertificate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var dpsCertificate = new AzureNative.Devices.DpsCertificate("dpsCertificate", new()
 *     {
 *         CertificateName = "cert",
 *         Properties = new AzureNative.Devices.Inputs.CertificatePropertiesArgs
 *         {
 *             Certificate = "MA==",
 *         },
 *         ProvisioningServiceName = "myFirstProvisioningService",
 *         ResourceGroupName = "myResourceGroup",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/devices/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := devices.NewDpsCertificate(ctx, "dpsCertificate", &devices.DpsCertificateArgs{
 * 			CertificateName: pulumi.String("cert"),
 * 			Properties: &devices.CertificatePropertiesArgs{
 * 				Certificate: pulumi.String("MA=="),
 * 			},
 * 			ProvisioningServiceName: pulumi.String("myFirstProvisioningService"),
 * 			ResourceGroupName:       pulumi.String("myResourceGroup"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.devices.DpsCertificate;
 * import com.pulumi.azurenative.devices.DpsCertificateArgs;
 * import com.pulumi.azurenative.devices.inputs.CertificatePropertiesArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var dpsCertificate = new DpsCertificate("dpsCertificate", DpsCertificateArgs.builder()
 *             .certificateName("cert")
 *             .properties(CertificatePropertiesArgs.builder()
 *                 .certificate("MA==")
 *                 .build())
 *             .provisioningServiceName("myFirstProvisioningService")
 *             .resourceGroupName("myResourceGroup")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:devices:DpsCertificate cert /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Devices/provisioningServices/{provisioningServiceName}/certificates/{certificateName}
 * ```
 */
public class DpsCertificate internal constructor(
    override val javaResource: com.pulumi.azurenative.devices.DpsCertificate,
) : KotlinCustomResource(javaResource, DpsCertificateMapper) {
    /**
     * The entity tag.
     */
    public val etag: Output<String>
        get() = javaResource.etag().applyValue({ args0 -> args0 })

    /**
     * The name of the certificate.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * properties of a certificate
     */
    public val properties: Output<CertificatePropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.let({ args0 ->
                certificatePropertiesResponseToKotlin(args0)
            })
        })

    /**
     * Metadata pertaining to creation and last modification of the resource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * The resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object DpsCertificateMapper : ResourceMapper<DpsCertificate> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.devices.DpsCertificate::class == javaResource::class

    override fun map(javaResource: Resource): DpsCertificate = DpsCertificate(
        javaResource as
            com.pulumi.azurenative.devices.DpsCertificate,
    )
}

/**
 * @see [DpsCertificate].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [DpsCertificate].
 */
public suspend fun dpsCertificate(
    name: String,
    block: suspend DpsCertificateResourceBuilder.() -> Unit,
): DpsCertificate {
    val builder = DpsCertificateResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [DpsCertificate].
 * @param name The _unique_ name of the resulting resource.
 */
public fun dpsCertificate(name: String): DpsCertificate {
    val builder = DpsCertificateResourceBuilder()
    builder.name(name)
    return builder.build()
}
